@@ -4,5 +4,5 @@ from PyOfficeRobot.lib.CONST import SPLIT_LINE
 
 print(SPLIT_LINE)
 print('【PyOfficeRobot，微信机器人】')
-print('全部功能【https://www.python-office.com/office/robot.html')
+print('【全部功能】：https://www.python-office.com/office/robot.html')
 print(SPLIT_LINE)
\ No newline at end of file
